==> open-xchange-server_6.16.1.0.orig.tar.gz: open-xchange-server-6.16.1.0/src/com/openexchange/groupware/infostore/webdav/TouchInfoitemsWithExpiredLocksListener.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.infostore.webdav;

import com.openexchange.api2.OXException;
import com.openexchange.groupware.EnumComponent;
import com.openexchange.groupware.OXExceptionSource;
import com.openexchange.groupware.infostore.Classes;
import com.openexchange.groupware.infostore.InfostoreExceptionFactory;
import com.openexchange.groupware.infostore.InfostoreFacade;
import com.openexchange.sessiond.impl.SessionHolder;
import com.openexchange.tools.session.ServerSession;
import com.openexchange.tools.session.ServerSessionAdapter;

/**
 * {@link TouchInfoitemsWithExpiredLocksListener}
 * 
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
@OXExceptionSource(classId = Classes.COM_OPENEXCHANGE_GROUPWARE_INFOSTORE_WEBDAV_TOUCHINFOITEMSWITHEXPIREDLOCKSLISTENER, component = EnumComponent.INFOSTORE)
public class TouchInfoitemsWithExpiredLocksListener implements LockExpiryListener {

    private static final InfostoreExceptionFactory EXCEPTIONS = new InfostoreExceptionFactory(TouchInfoitemsWithExpiredLocksListener.class);

    private SessionHolder sessionHolder;

    private InfostoreFacade infostoreFacade;

    public TouchInfoitemsWithExpiredLocksListener(SessionHolder sessionHolder, InfostoreFacade infostoreFacade) {
        super();
        this.sessionHolder = sessionHolder;
        this.infostoreFacade = infostoreFacade;
    }
    
    public TouchInfoitemsWithExpiredLocksListener() {
        super();

    }

    public void lockExpired(Lock lock) throws OXException {
        ServerSession serverSession;
        serverSession = new ServerSessionAdapter(sessionHolder.getSessionObject(), sessionHolder.getContext());
        infostoreFacade.touch(lock.getEntity(), serverSession);
    }

    
    public SessionHolder getSessionHolder() {
        return sessionHolder;
    }

    
    public void setSessionHolder(SessionHolder sessionHolder) {
        this.sessionHolder = sessionHolder;
    }

    
    public InfostoreFacade getInfostoreFacade() {
        return infostoreFacade;
    }

    
    public void setInfostoreFacade(InfostoreFacade infostoreFacade) {
        this.infostoreFacade = infostoreFacade;
    }

    
    public static InfostoreExceptionFactory getEXCEPTIONS() {
        return EXCEPTIONS;
    }
    
    
}

==> open-xchange-server_6.20.8.0.orig.tar.gz: open-xchange-server-6.20.8.0/src/com/openexchange/groupware/infostore/webdav/TouchInfoitemsWithExpiredLocksListener.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.infostore.webdav;

import com.openexchange.api2.OXException;
import com.openexchange.groupware.infostore.InfostoreFacade;
import com.openexchange.tools.session.ServerSession;
import com.openexchange.tools.session.ServerSessionAdapter;
import com.openexchange.tools.session.SessionHolder;

/**
 * {@link TouchInfoitemsWithExpiredLocksListener}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class TouchInfoitemsWithExpiredLocksListener implements LockExpiryListener {

    private SessionHolder sessionHolder;

    private InfostoreFacade infostoreFacade;

    public TouchInfoitemsWithExpiredLocksListener(SessionHolder sessionHolder, InfostoreFacade infostoreFacade) {
        super();
        this.sessionHolder = sessionHolder;
        this.infostoreFacade = infostoreFacade;
    }

    public TouchInfoitemsWithExpiredLocksListener() {
        super();

    }

    public void lockExpired(Lock lock) throws OXException {
        ServerSession serverSession;
        serverSession = new ServerSessionAdapter(sessionHolder.getSessionObject(), sessionHolder.getContext());
        infostoreFacade.touch(lock.getEntity(), serverSession);
    }


    public SessionHolder getSessionHolder() {
        return sessionHolder;
    }


    public void setSessionHolder(SessionHolder sessionHolder) {
        this.sessionHolder = sessionHolder;
    }


    public InfostoreFacade getInfostoreFacade() {
        return infostoreFacade;
    }


    public void setInfostoreFacade(InfostoreFacade infostoreFacade) {
        this.infostoreFacade = infostoreFacade;
    }
}
